package
Version:
v0.4.0
Opens a new window with list of versions in this module.
Published: May 30, 2026
License: MIT
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
GoFiles returns Go source files under Root after applying built-in excludes
and optional gitignore-style patterns.
type Options struct {
Root string
UseGitignore bool
IncludeTestdata bool
}
Options controls Go source file discovery.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.