package
Version:
v0.4.0
Opens a new window with list of versions in this module.
Published: May 30, 2026
License: MIT
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
-
func Archive(ctx context.Context, root string, ref string) (string, func(), error)
-
func Numstat(ctx context.Context, root string, since string, until string) ([]byte, error)
-
func Root(ctx context.Context, root string) (string, error)
Archive extracts ref into a temporary directory without changing the worktree.
Numstat returns git log --numstat output for the repository containing root.
Root returns the top-level directory for the Git repository containing root.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.